@@ -2,8 +2,6 @@
 # Author: Grigoriy Petukhov (http://lorien.name)
 # License: BSD
 import logging
-import os.path
-from datetime import datetime
 
 from django.core.management.base import BaseCommand
 
