@@ -5,7 +5,15 @@
 from urlparse import urlsplit
 import re
 from grab.tools.lxml_tools import clean_html
-import transliterate
+
+# Compatibility with transliterate < 1.4
+try:
+    from transliterate import autodiscover
+except ImportError:
+    pass
+else:
+    autodiscover()
+
 from transliterate.utils import translit
 
 from django.db import models
@@ -17,8 +25,6 @@ from django.utils.text import slugify
 from taggit.managers import TaggableManager
 from taggit.models import GenericTaggedItemBase, TagBase
 
-transliterate.autodiscover()
-
 
 class Feed(models.Model):
     title = models.CharField(_('title'), max_length=255)
