@@ -14,13 +14,15 @@ extract tags.
 # Author: Grigoriy Petukhov (http://lorien.name)
 # License: BSD
 import locale
-import sha
+import hashlib
 import re
 from time import mktime
 from datetime import datetime
 import feedparser
 import logging
 from grab.tools.lxml_tools import clean_html
+from lxml.etree import XMLSyntaxError
+
 
 log = logging.getLogger('feedzilla.util.parse')
 
@@ -181,7 +183,7 @@ def parse_feed(url=None, source_data=None, summary_size=1000, etag=None):
                 #continue
 
             tags = get_tags(entry)
-            guid = sha.new(link.encode('utf-8')).hexdigest()
+            guid = hashlib.sha1(link.encode('utf-8')).hexdigest()
 
             entry = {
                 'title': title,
@@ -193,7 +195,9 @@ def parse_feed(url=None, source_data=None, summary_size=1000, etag=None):
                 'tags': tags,
             }
             resp['entries'].append(entry)
+        except XMLSyntaxError:
+            logging.warning('Error parsing blog feed. Invalid XML syntax.')
         except Exception, ex:
-            logging.error(ex)
+            logging.exception(ex)
 
     return resp
